@@ -17,9 +17,9 @@
 #' }
 #'
 #' @export
-sim_article <- function(...) {
+sim_article <- function(..., highlight = NULL, citation_package = "natbib") {
   inherit_pdf_document(...,
                        template = find_resource("sim_article", "template.tex"),
-                       highlight = NULL,
-                       citation_package = "natbib")
+                       highlight = highlight,
+                       citation_package = citation_package)
 }
